[libpng16] Imported from libpng-1.6.20rc01.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index 0a57eff..d33fc1e 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.20rc01 - November 25, 2015
+Libpng 1.6.20rc01 - November 26, 2015
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -34,10 +34,10 @@
     not info_ptr, that left png_set_PLTE() open to the CVE-2015-8126
     vulnerability.
 
-Version 1.6.20beta03 [November 25, 2015]
+Version 1.6.20beta03 [November 26, 2015]
   Backported tests from libpng-1.7.0beta69.
  
-Version 1.6.20rc01 [November 25, 2015]
+Version 1.6.20rc01 [November 26, 2015]
   Fixed an error in handling of bad zlib CMINFO field, found by American
     Fuzzy Lop, reported by Brian Carpenter.  inflate() doesn't immediately
     fault a bad CMINFO field; instead a 'too far back' error happens later
diff --git a/CHANGES b/CHANGES
index 20f1729..991e84e 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5426,7 +5426,7 @@
 Version 1.6.20beta03 [November 24, 2015]
   Backported tests from libpng-1.7.0beta69.
 
-Version 1.6.20rc01 [November 25, 2015]
+Version 1.6.20rc01 [November 26, 2015]
   Fixed an error in handling of bad zlib CMINFO field, found by American
     Fuzzy Lop, reported by Brian Carpenter.  inflate() doesn't immediately
     fault a bad CMINFO field; instead a 'too far back' error happens later
diff --git a/CMakeLists.txt b/CMakeLists.txt
index ad7d4f7..da07c00 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -261,7 +261,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 16.${PNGLIB_RELEASE}.1.6.20beta03
+#   VERSION 16.${PNGLIB_RELEASE}.1.6.20rc01
     VERSION 16.${PNGLIB_RELEASE}.0
     SOVERSION 16
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index a8865fb..4ea4b49 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.0.7, July 1, 2000, through 1.6.20beta03, November 24, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.20rc01, November 26, 2015, are
 Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
 derived from libpng-1.0.6, and are distributed according to the same
 disclaimer and license as libpng-1.0.6 with the following individuals
@@ -109,4 +109,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-November 24, 2015
+November 26, 2015
diff --git a/README b/README
index 3772492..0d2489a 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.6.20beta03 - November 24, 2015 (shared library 16.0)
+README for libpng version 1.6.20rc01 - November 26, 2015 (shared library 16.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index 5313dd2..4c1c16c 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng],[1.6.20beta03],[png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng],[1.6.20rc01],[png-mng-implement@lists.sourceforge.net])
 AC_CONFIG_MACRO_DIR([scripts])
 
 # libpng does not follow GNU file name conventions (hence 'foreign')
@@ -39,7 +39,7 @@
 dnl AM_PREREQ([1.11.2])
 dnl stop configure from automagically running automake
 
-PNGLIB_VERSION=1.6.20beta03
+PNGLIB_VERSION=1.6.20rc01
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=6
 PNGLIB_RELEASE=20
diff --git a/contrib/arm-neon/linux-auxv.c b/contrib/arm-neon/linux-auxv.c
index 696e297..4d26bd3 100644
--- a/contrib/arm-neon/linux-auxv.c
+++ b/contrib/arm-neon/linux-auxv.c
@@ -7,7 +7,7 @@
  * This code is released under the libpng license.
  * For conditions of distribution and use, see the disclaimer
  * and license in png.h
- * 
+ *
  * SEE contrib/arm-neon/README before reporting bugs
  *
  * STATUS: COMPILED, TESTED
diff --git a/contrib/arm-neon/linux.c b/contrib/arm-neon/linux.c
index abae9e3..94f9bb1 100644
--- a/contrib/arm-neon/linux.c
+++ b/contrib/arm-neon/linux.c
@@ -72,7 +72,7 @@
                      state = Colon;
                   break;
                }
-               
+
                /* did not match 'feature' */
                state = SkipLine;
                /* FALL THROUGH */
diff --git a/contrib/examples/simpleover.c b/contrib/examples/simpleover.c
index 6852a95..59dd313 100644
--- a/contrib/examples/simpleover.c
+++ b/contrib/examples/simpleover.c
@@ -136,7 +136,7 @@
             /* This is the optimized Porter-Duff 'Over' operation, when the
              * input alpha is 0 the output is not changed.
              */
-            if (in_alpha > 0) 
+            if (in_alpha > 0)
             {
                png_uint_16 *out_pixel = sprite->buffer +
                   ((y+y_offset) * sprite->width + (x+x_offset))*4;
@@ -184,7 +184,7 @@
    }
 }
 
-static int 
+static int
 create_sprite(struct sprite *sprite, int *argc, const char ***argv)
 {
    /* Read the arguments and create this sprite. The sprite buffer has already
@@ -415,7 +415,7 @@
             n = sscanf(argv[0], "--sprite=%u,%u,%" str(sprite_name_chars) "s%c",
                 &sprites[nsprites].width, &sprites[nsprites].height,
                 sprites[nsprites].name, &tombstone);
-            
+
             if ((n == 2 || n == 3) &&
                 sprites[nsprites].width > 0 && sprites[nsprites].height > 0)
             {
@@ -492,7 +492,7 @@
                if (!add_sprite(output, out_buf, sprites+isprite, &argc, &argv))
                   goto out; /* error in add_sprite */
 
-               break; 
+               break;
             }
          }
 
diff --git a/contrib/gregbook/rpng2-win.c b/contrib/gregbook/rpng2-win.c
index eda176e..a7b9dfa 100644
--- a/contrib/gregbook/rpng2-win.c
+++ b/contrib/gregbook/rpng2-win.c
@@ -33,7 +33,7 @@
     - 2.02:  fixed improper display of usage screen on PNG error(s); fixed
               unexpected-EOF and file-read-error cases
     - 2.03:  removed runtime MMX-enabling/disabling and obsolete -mmx* options
-    - 2.04:  
+    - 2.04:
              (GR-P)
 
   ---------------------------------------------------------------------------
diff --git a/contrib/gregbook/rpng2-x.c b/contrib/gregbook/rpng2-x.c
index eea95fb..0c8ddeb 100644
--- a/contrib/gregbook/rpng2-x.c
+++ b/contrib/gregbook/rpng2-x.c
@@ -496,12 +496,12 @@
           "\t\t  transparent images; overrides -bgcolor\n",
           num_bgpat-1);
 #ifdef FEATURE_LOOP
-        fprintf(stderr, 
+        fprintf(stderr,
           "    -loop\tloops through background images after initial display\n"
           "\t\t  is complete (depends on -bgpat)\n"
           "    sec \tseconds to display each background image (default = 2)\n");
 #endif
-        fprintf(stderr, 
+        fprintf(stderr,
           "    dur \tduration in microseconds to wait after displaying each\n"
           "\t\t  row (for demo purposes)\n"
           "    -timing\tenables delay for every block read, to simulate modem\n"
diff --git a/contrib/libtests/makepng.c b/contrib/libtests/makepng.c
index 1d3a0ad..60d96d1 100644
--- a/contrib/libtests/makepng.c
+++ b/contrib/libtests/makepng.c
@@ -392,7 +392,7 @@
    unsigned int *colors, int small)
 {
    int filters = 0; /* file *MASK*, 0 means the default, not NONE */
-   png_uint_32 size_max = 
+   png_uint_32 size_max =
       image_size_of_type(color_type, bit_depth, colors, small)-1;
    png_uint_32 depth_max = (1U << bit_depth)-1; /* up to 65536 */
 
@@ -526,7 +526,7 @@
             assert(0/*NOT REACHED*/);
       }
    }
-      
+
    else switch (channels_of_type(color_type))
    {
    /* 1 channel: a square image with a diamond, the least luminous colors are on
@@ -1913,7 +1913,7 @@
       };
 
       chunk_insert *new_insert;
-      
+
       new_insert = add_tEXt("Copyright", copyright);
       if (new_insert != NULL)
       {
diff --git a/contrib/libtests/pngimage.c b/contrib/libtests/pngimage.c
index 58bb9a1..b91d0cd 100644
--- a/contrib/libtests/pngimage.c
+++ b/contrib/libtests/pngimage.c
@@ -948,7 +948,7 @@
 
          if ((transform_info[i].valid_chunks == 0 ||
                (transform_info[i].valid_chunks & chunks) != 0) &&
-            (transform_info[i].color_mask_required & ct) == 
+            (transform_info[i].color_mask_required & ct) ==
                transform_info[i].color_mask_required &&
             (transform_info[i].color_mask_absent & ct) == 0 &&
             (transform_info[i].bit_depths & bd) != 0 &&
@@ -1006,7 +1006,7 @@
    {
       unsigned long chunks =
          png_get_valid(dp->read_pp, dp->read_ip, 0xffffffff);
-      
+
       if (chunks != dp->chunks)
          display_log(dp, APP_FAIL, "PNG chunks changed from 0x%lx to 0x%lx",
             (unsigned long)dp->chunks, chunks);
diff --git a/contrib/libtests/pngstest.c b/contrib/libtests/pngstest.c
index 44267b4..3374c72 100644
--- a/contrib/libtests/pngstest.c
+++ b/contrib/libtests/pngstest.c
@@ -3130,7 +3130,7 @@
         (void) unlink(tmpfile);
       }
 #endif
-      
+
       if (f != NULL)
       {
          if (png_image_write_to_stdio(&image->image, f, convert_to_8bit,
diff --git a/contrib/tools/genpng.c b/contrib/tools/genpng.c
index 44102b4..ce43260 100644
--- a/contrib/tools/genpng.c
+++ b/contrib/tools/genpng.c
@@ -324,7 +324,7 @@
                {
                   double wx = bicubic[abs(dx)][0];
 
-                  if (wx != 0 && arg->inside_fn(arg, x+dx/16, y+dy/16)) 
+                  if (wx != 0 && arg->inside_fn(arg, x+dx/16, y+dy/16))
                      alphay += wx;
                }
 
@@ -565,7 +565,7 @@
    /* The dot product is the distance down the line, the cross product is
     * the distance away from the line:
     *
-    *    distance = |cross| / sqrt(len2) 
+    *    distance = |cross| / sqrt(len2)
     */
    cross = x * ly - y * lx;
 
@@ -722,7 +722,7 @@
    /* 'a' may be negative or greater than 1; if it is, negative clamp the
     * pixel to 0 if >1 clamp r/g/b:
     */
-   if (a > 0) 
+   if (a > 0)
    {
       if (a > 1)
       {
diff --git a/contrib/tools/png-fix-itxt.c b/contrib/tools/png-fix-itxt.c
index 5730d9f..c7654c1 100644
--- a/contrib/tools/png-fix-itxt.c
+++ b/contrib/tools/png-fix-itxt.c
@@ -8,7 +8,7 @@
  * For conditions of distribution and use, see the disclaimer
  * and license in png.h
  *
- * Usage:            
+ * Usage:
  *
  *     png-fix-itxt.exe < bad.png > good.png
  *
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 75949f4..5af6ce5 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.6.20beta03 - November 24, 2015
+ libpng version 1.6.20rc01 - November 26, 2015
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.6.20beta03 - November 24, 2015
+ libpng versions 0.97, January 1998, through 1.6.20rc01 - November 26, 2015
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
 
@@ -5323,7 +5323,7 @@
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.20beta03 are Y2K compliant.  It is my belief that earlier
+upward through 1.6.20rc01 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has two year fields.  One is a 2-byte unsigned integer
diff --git a/libpng.3 b/libpng.3
index e917e61..fe7577e 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "November 24, 2015"
+.TH LIBPNG 3 "November 26, 2015"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.20beta03
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.20rc01
 .SH SYNOPSIS
 \fB
 #include <png.h>\fP
@@ -508,7 +508,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.6.20beta03 - November 24, 2015
+ libpng version 1.6.20rc01 - November 26, 2015
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -519,7 +519,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.6.20beta03 - November 24, 2015
+ libpng versions 0.97, January 1998, through 1.6.20rc01 - November 26, 2015
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2015 Glenn Randers-Pehrson
 
@@ -5831,7 +5831,7 @@
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.6.20beta03 are Y2K compliant.  It is my belief that earlier
+upward through 1.6.20rc01 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has two year fields.  One is a 2-byte unsigned integer
@@ -5933,7 +5933,7 @@
  ...
  1.5.23                  15    10523  15.so.15.23[.0]
  ...
- 1.6.19                  16    10619  16.so.16.19[.0]
+ 1.6.20                  16    10620  16.so.16.20[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -5989,7 +5989,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.6.20beta03 - November 24, 2015:
+Libpng version 1.6.20rc01 - November 26, 2015:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -6014,7 +6014,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.0.7, July 1, 2000, through 1.6.20beta03, November 24, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.6.20rc01, November 26, 2015, are
 Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
 derived from libpng-1.0.6, and are distributed according to the same
 disclaimer and license as libpng-1.0.6 with the following individuals
@@ -6113,7 +6113,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-November 24, 2015
+November 26, 2015
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index e8fd083..e6d9dc0 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "November 24, 2015"
+.TH LIBPNGPF 3 "November 26, 2015"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.20beta03
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.20rc01
 (private functions)
 .SH SYNOPSIS
 \fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 0fca673..1044a35 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "November 24, 2015"
+.TH PNG 5 "November 26, 2015"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 6dc0696..6baa331 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_20beta03 Your_png_h_is_not_version_1_6_20beta03;
+typedef png_libpng_version_1_6_20rc01 Your_png_h_is_not_version_1_6_20rc01;
 
 /* Tells libpng that we have already handled the first "num_bytes" bytes
  * of the PNG file signature.  If the PNG data is embedded into another
@@ -775,13 +775,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-      "libpng version 1.6.20beta03 - November 24, 2015" PNG_STRING_NEWLINE \
+      "libpng version 1.6.20rc01 - November 26, 2015" PNG_STRING_NEWLINE \
       "Copyright (c) 1998-2015 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
       "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
       "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
       PNG_STRING_NEWLINE;
 #  else
-   return "libpng version 1.6.20beta03 - November 24, 2015\
+   return "libpng version 1.6.20rc01 - November 26, 2015\
       Copyright (c) 1998-2015 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 15640dc..ed7bfd9 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.6.20beta03, November 24, 2015
+ * libpng version 1.6.20rc01, November 26, 2015
  *
  * Copyright (c) 1998-2015 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index b12214d..48c3aed 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -2070,4 +2070,4 @@
 #endif
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_20beta03 Your_png_h_is_not_version_1_6_20beta03;
+typedef png_libpng_version_1_6_20rc01 Your_png_h_is_not_version_1_6_20rc01;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index baead4f..52b9561 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.6.20beta03 - November 24, 2015
+libpng version 1.6.20rc01 - November 26, 2015
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index a512d3d..0848976 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.6.20beta03 - November 24, 2015
+ * libpng version 1.6.20rc01 - November 26, 2015
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 876c279..bba2bfd 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
 
-Makefiles for  libpng version 1.6.20beta03 - November 24, 2015
+Makefiles for  libpng version 1.6.20rc01 - November 26, 2015
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng16.so.16.1.6.20beta03)
+                       (gcc, creates libpng16.so.16.1.6.20rc01)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -33,12 +33,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires libpng.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng16.so.16.1.6.20beta03)
+                       creates libpng16.so.16.1.6.20rc01)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng16.so.16.1.6.20beta03)
+                       creates libpng16.so.16.1.6.20rc01)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng16.so.16.1.6.20beta03)
+                       creates libpng16.so.16.1.6.20rc01)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/def.c b/scripts/def.c
index a21f373..1848a4b 100644
--- a/scripts/def.c
+++ b/scripts/def.c
@@ -21,7 +21,7 @@
 PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
 PNG_DFN ""
 PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.6.20beta03"
+PNG_DFN ";Version 1.6.20rc01"
 
 #define PNG_EXPORTA(ordinal, type, name, args, attributes)\
         PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 007adf5..cfd5651 100644
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.6.20beta03
+version=1.6.20rc01
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 8e0cefc..247356c 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.6.20beta03
+Version: 1.6.20rc01
 Libs: -L${libdir} -lpng16
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 2955a50..5061401 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png16
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.6.20beta03
+SHLIB_MINOR=	1.6.20rc01
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index c15d543..2e5ebdf 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	16
-SHLIB_MINOR=	1.6.20beta03
+SHLIB_MINOR=	1.6.20rc01
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index f58fbfa..f1508a5 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	16
-SHLIB_MINOR=	1.6.20beta03
+SHLIB_MINOR=	1.6.20rc01
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 8f6d6a4..6e9f85f 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,8 +1,8 @@
-/* libpng 1.6.20beta03 STANDARD API DEFINITION */
+/* libpng 1.6.20rc01 STANDARD API DEFINITION */
 
 /* pnglibconf.h - library build configuration */
 
-/* Libpng version 1.6.20beta03 - November 24, 2015 */
+/* Libpng version 1.6.20rc01 - November 26, 2015 */
 
 /* Copyright (c) 1998-2015 Glenn Randers-Pehrson */
 
diff --git a/scripts/symbols.def b/scripts/symbols.def
index f18aded..91f776f 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.6.20beta03
+;Version 1.6.20rc01
 ;--------------------------------------------------------------
 ; LIBPNG symbol list as a Win32 DEF file
 ; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index e653c91..f549db4 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.6.20beta03, November 24, 2015
  *
  * Copyright (c) 1998-2015 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.6.20beta03, November 24, 2015:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
  */
@@ -25,7 +25,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.0.7, July 1, 2000, through 1.6.20beta03, November 24, 2015, are
  * Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same
  * disclaimer and license as libpng-1.0.6 with the following individuals
@@ -186,7 +186,7 @@
  *    ...
  *    1.5.23                  15    10523  15.so.15.23[.0]
  *    ...
- *    1.6.19                  16    10619  16.so.16.19[.0]
+ *    1.6.20                  16    10620  16.so.16.20[.0]
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -214,13 +214,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    November 24, 2015
+ *    November 26, 2015
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.6.20beta03 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *
  *    Libpng only has two year fields.  One is a 2-byte unsigned integer
@@ -282,9 +282,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.20beta03"
+#define PNG_LIBPNG_VER_STRING "1.6.20rc01"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.6.20beta03 - November 24, 2015\n"
+     " libpng version 1.6.20rc01 - November 26, 2015\n"
 
 #define PNG_LIBPNG_VER_SONUM   16
 #define PNG_LIBPNG_VER_DLLNUM  16
@@ -298,7 +298,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  03
+#define PNG_LIBPNG_VER_BUILD  01
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -315,7 +315,7 @@
 #define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
                                        PNG_LIBPNG_BUILD_PRIVATE */
 
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_BETA
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
 
 /* Careful here.  At one time, Guy wanted to use 082, but that would be octal.
  * We must not include leading zeros.
@@ -433,7 +433,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef char* png_libpng_version_1_6_20beta03;
+typedef char* png_libpng_version_1_6_20rc01;
 
 /* Basic control structions.  Read libpng-manual.txt or libpng.3 for more info.
  *
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.6.20beta03, November 24, 2015
+ * libpng version 1.6.20rc01, November 26, 2015
  *
  * Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.6.20beta03, November 24, 2015:
+ *   libpng versions 0.97, January 1998, through 1.6.20rc01, November 26, 2015:
  *     Glenn Randers-Pehrson.
  *   See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.0.7, July 1, 2000, through 1.6.20beta03, November 24, 2015, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.6.20rc01, November 26, 2015, are
  * Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, are
  * derived from libpng-1.0.6, and are distributed according to the same
@@ -214,13 +214,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.6.20beta03 are Y2K compliant.  It is my belief that
+ *    upward through 1.6.20rc01 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *